pm4py.statistics package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.attributes
   pm4py.statistics.concurrent_activities
   pm4py.statistics.end_activities
   pm4py.statistics.eventually_follows
   pm4py.statistics.ocel
   pm4py.statistics.overlap
   pm4py.statistics.passed_time
   pm4py.statistics.performance_spectrum
   pm4py.statistics.rework
   pm4py.statistics.sojourn_time
   pm4py.statistics.start_activities
   pm4py.statistics.traces
   pm4py.statistics.util
   pm4py.statistics.variants

Submodules
----------

pm4py.statistics.parameters module
----------------------------------

.. automodule:: pm4py.statistics.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics
   :members:
   :undoc-members:
   :show-inheritance:
